package com.platform.yijia.controller;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.platform.yijia.config.YiJiaRequest;
import com.platform.yijia.pojo.Coupon;
import com.platform.yijia.pojo.CouponIssue;
import com.platform.yijia.pojo.UserCoupon;
import com.platform.yijia.service.CouponService;
import com.platform.yijia.utils.CodeMsg;
import com.platform.yijia.utils.ResultData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/*
 * <Title> CouponController </Title>
 * <Description> 优惠券 </Description>
 * @Author JK
 * @Date 2021年7月6日
 */
@RestController
@YiJiaRequest()
@CrossOrigin
@Api(tags = "优惠券")
public class CouponController {
    private static Logger logger =(Logger) LoggerFactory.getLogger(CouponController.class);

    @Resource
    private CouponService couponService;


    /**
     * 获取油站分发优惠券
     * @param stationId  油站ID
     * @param couponIssueId    发放方式ID
     * @param unionId    用户unionId
     * @return
     */
    @RequestMapping(value = "/selectStaGrantCouponList", method = RequestMethod.GET)
    @Transactional
    @ApiOperation(value = "获取油站已发放的优惠券信息", httpMethod = "GET", notes = "获取油站已发放的优惠券信息")
    public String selectStaGrantCouponList(@ApiParam(value = "油站ID", required = true) @RequestParam Integer stationId,
                                           @ApiParam(value = "发放方式ID", required = true) @RequestParam Integer couponIssueId,
                                           @ApiParam(value = "用户unionId", required = true) @RequestParam String unionId){
        Gson gson =new GsonBuilder().setDateFormat("yyyy-MM-dd HH:mm:ss").create();
        ResultData resultData = null;
        try {
            Coupon coupon = new Coupon();
            coupon.setStationId(stationId);
            coupon.setCouponIssueId(couponIssueId);
            coupon.setUnionId(unionId);
            //领取油站所分发的优惠券
            List<Coupon> coupons = couponService.selectStaGrantCouponList(coupon);
            resultData = ResultData.success(coupons);
        }catch (Exception e){
            logger.error("获取油站已发放的优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.SEARCH_FAIL);
        }
        return  gson.toJson(resultData);
    }


    //获取优惠券信息
    @RequestMapping(value = "/selectCouponInfo", method = RequestMethod.GET)
    @ApiOperation(value = "获取优惠券信息", httpMethod = "GET", notes = "获取优惠券信息")
    public String selectCouponInfo(@ApiParam(value = "优惠券ID", required = true) @RequestParam Integer id){
        Gson gson =new Gson();
        ResultData resultData = null;
        try {
            Coupon coupon = new Coupon();
            coupon.setId(id);
            Coupon couponInfo = couponService.selectCouponInfo(coupon);
            resultData = ResultData.success(couponInfo);
        }catch (Exception e){
            logger.error("获取优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.SEARCH_FAIL);
        }
        return  gson.toJson(resultData);
    }

    //获取客户所拥有的优惠券
    @RequestMapping(value = "/selectUserCoupons", method = RequestMethod.GET)
    @ApiOperation(value = "获取客户所拥有的优惠券", httpMethod = "GET", notes = "获取客户所拥有的优惠券")
    public String selectUserCoupons(@ApiParam(value = "油站ID", required = true) @RequestParam Integer stationId,
                                    @ApiParam(value = "用户unionId", required = true) @RequestParam String unionId){
        Gson gson =new Gson();
        ResultData resultData = null;
        try {
            UserCoupon userCoupon = new UserCoupon();
            userCoupon.setStationId(stationId);
            userCoupon.setUnionId(unionId);
            List<UserCoupon> userCoupons = couponService.selectUserCoupons(userCoupon);
            resultData = ResultData.success(userCoupons);
        }catch (Exception e){
            logger.error("获取客户所拥有的优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.SEARCH_FAIL);
        }
        return  gson.toJson(resultData);
    }

    //用户领取优惠券
    @RequestMapping(value = "/addUserCoupon", method = RequestMethod.GET)
    @Transactional
    @ApiOperation(value = "用户领取优惠券", httpMethod = "GET", notes = "用户领取优惠券")
    public String addUserCoupon(@ApiParam(value = "用户unionId", required = true) @RequestParam String unionId,
                                @ApiParam(value = "优惠券IDS", required = true) @RequestParam ArrayList<String> ids,
                                @ApiParam(value = "领取方式ID", required = true) @RequestParam Integer couponIssueId,
                                @ApiParam(value = "油站ID", required = true) @RequestParam Integer stationId){
        Gson gson = new Gson();
        ResultData resultData = null;
        try{
            //获取领取方式信息
            CouponIssue couponIssue = new CouponIssue();
            couponIssue.setStationId(stationId);
            couponIssue.setCouponIssueId(couponIssueId);
            List<CouponIssue> couponIssueList = couponService.selectCouponIssueList(couponIssue);
            if(couponIssueList !=null && couponIssueList.size() ==1){
                //int size = ids.size();
                for(int i=0; i<ids.size(); i++){

                }
            }else {
                resultData = ResultData.error(CodeMsg.YEWU_FAIL,"该领取方式不存在");
            }
        }catch (Exception e){
            logger.error("用户领取优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.INSERT_FAIL);
        }
        return gson.toJson(resultData);
    }

}
